@@ -14,17 +14,18 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 
 from more import ButtonMenu, FlowLayout, get_sid, ClientServiceThread, \
-                 get_view_params, show_msg
+                 get_view_params, show_msg, client_list_methods, get_system_rgb, \
+                 get_icon
 
-class DisplayMethod(QtGui.QWidget):
+class DisplayMethod(qt.QWidget):
     def __init__(self, parent, ClientObj):
         super(DisplayMethod, self).__init__(parent)
         self.ClientObj = ClientObj
         self._parent = parent
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
         ClientObj.back_step_list = []
 
     def initUI(self, results):
@@ -34,39 +35,13 @@ class DisplayMethod(QtGui.QWidget):
         IMAGE = 3 # Getting image path
         self.lable_list = []
         self.button_list = {}
-        self.layout = QtGui.QVBoxLayout()
+        self.layout = qt.QVBoxLayout()
         self.groupbox_dict = {}
         self.layout_dict = {}
 
         # set new Title
         self.ClientObj._parent.setWindowTitle(self.ClientObj.Name)
 
-        background_color = 'rgb(255,255,255)'
-        self._parent.main_frame.viewport().setStyleSheet(\
-        "background-color: %s ; " %background_color
-        )
-
-        self.setStyleSheet(self.styleSheet() + \
-            'QWidget { background: transparent;}'
-
-            'QGroupBox {font-weight: bold;'
-            'border: 1px solid gray;'
-            'border-left-color: qlineargradient( x1: 0, y1: 0, x2: 0, y2: 1,'
-                                        'stop: 0 gray, stop: 1 transparent);'
-            'border-top-color: qlineargradient( x1: 0, y1: 0, x2: 1, y2: 0,'
-                                       'stop: 0 gray, stop: 1 transparent);'
-            'border-right: 0px; border-bottom: 0px;'
-            'border-top-left-radius: 2px;'
-
-            'background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1,'
-            'stop: 0 rgb(230, 230, 230), stop: 0.5 transparent,'
-            'stop: 1 transparent);'
-            'padding-top: 18px; padding-bottom: 18px;}'
-            'QGroupBox::title {background-color: transparent;'
-
-            'color: #555; subcontrol-position: top left;'
-            'margin-top: 6px; margin-left: 8px;}')
-
         # transform a list into the dictionary {'group': [methods], ...}
         guiMethods = {}
         if type(results) == int:
@@ -95,10 +70,10 @@ class DisplayMethod(QtGui.QWidget):
                 sub_group = group.split('.')[1].encode('utf-8')
                 if not self.groupbox_dict.has_key(group_name):
                     self.groupbox_dict[group_name] = \
-                              QtGui.QGroupBox(group_name.decode('utf-8'), self)
+                              qt.QGroupBox(group_name.decode('utf-8'), self)
 
                     self.groupbox_dict[group_name].setAlignment \
-                                                        (QtCore.Qt.AlignLeft)
+                                                        (qt.Qt.AlignLeft)
 
                 if not self.layout_dict.has_key(group_name):
                     self.layout_dict[group_name] = \
@@ -131,8 +106,8 @@ class DisplayMethod(QtGui.QWidget):
 
             if not self.groupbox_dict.has_key(group):
                 self.groupbox_dict[group] = \
-                                QtGui.QGroupBox(group, self)
-                self.groupbox_dict[group].setAlignment(QtCore.Qt.AlignLeft)
+                                qt.QGroupBox(group, self)
+                self.groupbox_dict[group].setAlignment(qt.Qt.AlignLeft)
 
             if not self.layout_dict.has_key(group):
                 self.layout_dict[group] = FlowLayout(self.groupbox_dict[group])
@@ -164,8 +139,8 @@ class DisplayMethod(QtGui.QWidget):
                                 (self.button_list[group]\
                                 [len(self.button_list[group]) - 1])
 
-            self.layout_dict[group].setAlignment(QtCore.Qt.AlignLeft | \
-                                                       QtCore.Qt.AlignTop)
+            self.layout_dict[group].setAlignment(qt.Qt.AlignLeft | \
+                                                       qt.Qt.AlignTop)
             self.groupbox_dict[group].setLayout(self.layout_dict[group])
 
         keys_sort = guiMethods.keys()
@@ -186,7 +161,7 @@ class DisplayMethod(QtGui.QWidget):
                                 (self.button_list[sub_group]\
                                 [len(self.button_list[sub_group]) - 1])
 
-                self.layout_dict[group_name].setAlignment(QtCore.Qt.AlignLeft)
+                self.layout_dict[group_name].setAlignment(qt.Qt.AlignLeft)
                 if self.groupbox_dict[group_name]:
                     self.groupbox_dict[group_name].setLayout \
                                                 (self.layout_dict[group_name])
@@ -199,11 +174,51 @@ class DisplayMethod(QtGui.QWidget):
                 self.layout.addWidget(self.groupbox_dict[group])
                 self.groupbox_dict[group] = None
 
-        self.layout.setAlignment(QtCore.Qt.AlignTop)
+        self.layout.setAlignment(qt.Qt.AlignTop)
         self.setLayout(self.layout)
         self.resize(self.layout.sizeHint())
+        self.updateColors()
+
+    def updateColors(self):
+        background_color = get_system_rgb(self._parent.main_frame, qt.QPalette.Base)
+        self._parent.main_frame.viewport().setStyleSheet(
+            "background-color: %s ; " %background_color
+        )
+        text_color = "rgb(160,160,160)"
+        self.setStyleSheet(self.styleSheet() + \
+            'QWidget { background: transparent;}'
+
+            'QGroupBox {font-weight: bold;'
+            'border: 1px solid gray;'
+            'border-left-color: qlineargradient( x1: 0, y1: 0, x2: 0, y2: 1,'
+                                        'stop: 0 gray, stop: 1 transparent);'
+            'border-top-color: qlineargradient( x1: 0, y1: 0, x2: 1, y2: 0,'
+                                       'stop: 0 gray, stop: 1 transparent);'
+            'border-right: 0px; border-bottom: 0px;'
+            'border-top-left-radius: 2px;'
+
+            'background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 1,'
+            'stop: 0 rgba(200, 200, 200,75), stop: 0.5 transparent,'
+            'stop: 1 transparent);'
+            'padding-top: 18px; padding-bottom: 18px;}'
+            'QGroupBox::title {background-color: transparent;'
+
+            'color: %s; subcontrol-position: top left;'
+            'margin-top: 6px; margin-left: 8px;}'%text_color)
+
+        for group in self.button_list.values():
+            for button in group:
+                button.updateColors()
+
+    def disableButtons(self):
+        for group in self.button_list.values():
+            for button in group:
+                button.setEnabled(False)
+                button.updateColors()
 
     def refresh(self):
+        self.ClientObj.methods_list = client_list_methods(self.ClientObj.sid,
+            self.ClientObj.client)
         results = self.ClientObj.methods_list
         self.initUI(results)
         self.ClientObj.app.processEvents()
@@ -212,12 +227,14 @@ class DisplayMethod(QtGui.QWidget):
                     self._parent.main_frame.viewport().palette()
         self.ClientObj._parent.setWindowTitle(_("Calculate Console"))
 
+
     def onActivated(self):
         # Call server method
         if hasattr (self, 'onActivated_thread'):
             if self.onActivated_thread.isRunning():
                 return 1
-        self.setDisabled(True)
+        self.setEnabled(False)
+        self.updateColors()
         method_name = self.sender().objectName()
 #        view_method_name = self.sender().text()
         step = 0
@@ -225,11 +242,17 @@ class DisplayMethod(QtGui.QWidget):
         self.ClientObj.method_name = method_name
 
         self.ClientObj.sid = get_sid(self.ClientObj.client)
+        expert = None
         if self.ClientObj.param_objects.has_key(method_name):
             self.ClientObj.param_objects[method_name]['step'] = 0
+            if self.ClientObj.param_objects[method_name]['expert_changed']:
+                expert = True
+
 
         view_params = get_view_params(self.ClientObj.client, \
-                       str(method_name + '_view'), step = step, brief = brief)
+                       str(method_name + '_view'), step = step,
+                       expert = expert,
+                       brief = brief)
         self.onActivated_thread = ClientServiceThread(self.ClientObj, \
                         str(method_name + '_view'), int(self.ClientObj.sid), \
                         view_params, return_except = True)
@@ -271,15 +294,15 @@ class DisplayMethod(QtGui.QWidget):
             self.ClientObj.MainWidget.delete_MainFrameWgt()
 
             self.ClientObj.MainWidget.MainFrameWgt = \
-                                      QtGui.QWidget(self.ClientObj.MainWidget)
+                                      qt.QWidget(self.ClientObj.MainWidget)
             if not back:
                 # save data for a step back
                 self.ClientObj.back_step_list.append ([groups, sub_group, \
                                     self.ClientObj._parent.windowTitle()])
 
-            hlayout = QtGui.QHBoxLayout()
-            hlayout.addItem(QtGui.QSpacerItem( 0, 0, \
-                    QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding))
+            hlayout = qt.QHBoxLayout()
+            hlayout.addItem(qt.QSpacerItem( 0, 0, \
+                    qt.QSizePolicy.Expanding, qt.QSizePolicy.Expanding))
             self.ClientObj.MainWidget.MainFrameWgt.setLayout(hlayout)
 
             self.ClientObj.MainWidget.main_frame.setWidget \
@@ -311,30 +334,30 @@ class DisplayMethod(QtGui.QWidget):
                 self.onActivated_thread.wait()
         event.accept()
 
-class StartWidget(QtGui.QWidget):
+class StartWidget(qt.QWidget):
     def __init__(self, parent):
         super(StartWidget, self).__init__(parent)
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
-class ConnectLostLabel (QtGui.QWidget):
+class ConnectLostLabel (qt.QWidget):
     def __init__(self, text, parent, reconnect = False):
-        QtGui.QWidget.__init__(self, parent.layout_wgt)
+        qt.QWidget.__init__(self, parent.layout_wgt)
         self._parent = parent
         if parent.main_frame.isEnabled():
             parent.left_frame.setDisabled(True)
             parent.main_frame.setDisabled(True)
             parent.control_button.setDisabled(True)
 
-        white_layout = QtGui.QVBoxLayout(self)
-        lbl = QtGui.QLabel(text + '\n\n', self)
+        white_layout = qt.QVBoxLayout(self)
+        lbl = qt.QLabel(text + '\n\n', self)
         white_layout.addWidget(lbl)
 
         self.setStyleSheet ('background-color: rgba(250,250,250,200);'
                             'border-radius: 2px;')
 
         if reconnect:
-            self.reconnect_button = QtGui.QPushButton(_('Reconnect'), self)
-            self.reconnect_button.setIcon(QtGui.QIcon.fromTheme('view-refresh'))
+            self.reconnect_button = qt.QPushButton(_('Reconnect'), self)
+            self.reconnect_button.setIcon(get_icon('view-refresh'))
             self.reconnect_button.setStyleSheet('''
             QPushButton {
                  border: 2px solid #8f8f91;
@@ -357,19 +380,19 @@ class ConnectLostLabel (QtGui.QWidget):
                                    self.reconnect_button.sizeHint().height())
 
             self.reconnect_button.resize(self.reconnect_button.sizeHint() + \
-                                         QtCore.QSize(5,5))
+                                         qt.QSize(5,5))
             self.reconnect_button.show()
             self.reconnect_button.setEnabled(True)
 
-        lbl.setAlignment(QtCore.Qt.AlignCenter)
+        lbl.setAlignment(qt.Qt.AlignCenter)
         self.move(-10,-10)
-        self.resize(parent.layout_wgt.size() + QtCore.QSize(20,20))
+        self.resize(parent.layout_wgt.size() + qt.QSize(20,20))
 
         self.setEnabled(True)
 
     def resize_widget(self):
         cur_size = self._parent.size()
-        self.resize(cur_size + QtCore.QSize(20,20))
+        self.resize(cur_size + qt.QSize(20,20))
         if hasattr (self, 'reconnect_button'):
             self.reconnect_button.move(cur_size.width()/2 - \
                                    self.reconnect_button.sizeHint().width()/2,\
