@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 import urllib2 as u2
 if hasattr(u2,"ssl"):
     u2.ssl._create_default_https_context = u2.ssl._create_unverified_context
@@ -39,14 +39,14 @@ from more import show_msg, show_question, LabelWordWrap
 flag = 0
 log = getLogger(__name__)
 
-class AddServerCert (QtGui.QDialog):
+class AddServerCert (qt.QDialog):
     def __init__(self, parent, ClientObj, cert):
         super(AddServerCert, self).__init__()
         self.ClientObj = ClientObj
         self.parent = parent
         self.cert = cert
 
-        self.grid = QtGui.QGridLayout(self)
+        self.grid = qt.QGridLayout(self)
         self.lbl_list = []
 
         self.grid.addWidget(LabelWordWrap(_('Untrusted Server Certificate!'), \
@@ -59,10 +59,10 @@ class AddServerCert (QtGui.QDialog):
         self.grid.addWidget(LabelWordWrap (_('Serial Number =  %s') \
                             % certobj.get_serial_number(), self), 2, 0, 1, 3)
 
-        self.tab = QtGui.QTabWidget(self)
+        self.tab = qt.QTabWidget(self)
         # add Issuer tab
-        self.issuer_wgt = QtGui.QWidget(self)
-        self.issuer_layout = QtGui.QVBoxLayout()
+        self.issuer_wgt = qt.QWidget(self)
+        self.issuer_layout = qt.QVBoxLayout()
 
         Issuer = certobj.get_issuer().get_components()
         for i in Issuer:
@@ -73,8 +73,8 @@ class AddServerCert (QtGui.QDialog):
         self.tab.addTab(self.issuer_wgt, _('Issuer'))
 
         # add Subject tab
-        self.subject_wgt = QtGui.QWidget(self)
-        self.subject_layout = QtGui.QVBoxLayout()
+        self.subject_wgt = qt.QWidget(self)
+        self.subject_layout = qt.QVBoxLayout()
 
         Subject = certobj.get_subject().get_components()
         for item in Subject:
@@ -94,8 +94,8 @@ class AddServerCert (QtGui.QDialog):
                  (_("Add this server certificate to trusted or ") +\
                  _('try adding the CA and root certificates to trusted?'),self))
 
-        self.pix_lbl = QtGui.QLabel(self)
-        pi = QtGui.QPixmap()
+        self.pix_lbl = qt.QLabel(self)
+        pi = qt.QPixmap()
         pi.load('/usr/share/icons/oxygen/48x48/status/security-medium.png')
         self.pix_lbl.setPixmap(pi)
         self.grid.addWidget(self.pix_lbl, 0,0)
@@ -104,20 +104,20 @@ class AddServerCert (QtGui.QDialog):
             self.grid.addWidget(self.lbl_list[num_lbl], num_lbl + 8, 0, 1, 3)
 
         x = len (self.lbl_list) + 8
-        self.server_but = QtGui.QPushButton(_('Add the server certificate'),
+        self.server_but = qt.QPushButton(_('Add the server certificate'),
                                             self)
         self.server_but.clicked.connect(self.add_server)
         self.server_but.clicked.connect(self.close)
         self.grid.addWidget(self.server_but, x, 0)
 
-        self.ca_but = QtGui.QPushButton(_("Add the CA and root certificates"),
+        self.ca_but = qt.QPushButton(_("Add the CA and root certificates"),
                                         self)
         self.ca_but.clicked.connect(self.add_ca)
         self.ca_but.clicked.connect(self.add_server)
         self.ca_but.clicked.connect(self.close)
         self.grid.addWidget(self.ca_but, x, 1)
 
-        self.cancel_but = QtGui.QPushButton(_('Cancel'), self)
+        self.cancel_but = qt.QPushButton(_('Cancel'), self)
         self.cancel_but.clicked.connect(self.close)
         self.grid.addWidget(self.cancel_but, x, 2)
 
@@ -134,7 +134,7 @@ class AddServerCert (QtGui.QDialog):
         self.move(x, y)
         self.setFixedSize(self.sizeHint())
 
-        self.setAttribute(QtCore.Qt.WA_ShowModal)
+        self.setWindowModality(qt.Qt.WindowModal)
         self.flag = 4
 
     def add_server(self):
@@ -203,6 +203,7 @@ class Client_suds(Client):
         self.REQ_FILE =  path_to_cert + 'client.csr'
         self.PKEY_FILE = PKEY_FILE
         self.SID_FILE = path_to_cert + 'sids'
+        self.SID_LOCK = path_to_cert + 'sids.lock'
         self.CRL_PATH = path_to_cert + 'ca/crl/'
         if not os.path.exists(self.CRL_PATH):
             os.makedirs(self.CRL_PATH)
@@ -237,11 +238,11 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
 
         while True:
             if os.path.exists(user_root_cert):
-                result_user_root = self.connect_trusted_root(sock, \
+                result_user_root = self.connect_trusted_root(sock,
                                               user_root_cert, self.CRL_PATH)
             if result_user_root == 1:
-                glob_root_cert = self.ClientObj.VarsApi.Get \
-                                                      ('core.cl_glob_root_cert')
+                glob_root_cert = self.ClientObj.VarsApi.Get(
+                    'core.cl_glob_root_cert')
                 result_root_con = 1
                 if os.path.exists(glob_root_cert):
                     sock = socket.create_connection((self.host, self.port),
@@ -249,7 +250,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                     if self._tunnel_host:
                         self.sock = sock
                         self._tunnel()
-                    result_root_con = self.connect_trusted_root(sock, \
+                    result_root_con = self.connect_trusted_root(sock,
                                               glob_root_cert, self.CRL_PATH)
                 if result_root_con == 1:
                     sock = socket.create_connection((self.host, self.port),
@@ -257,8 +258,8 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                     if self._tunnel_host:
                         self.sock = sock
                         self._tunnel()
-                    result_server_con = self.connect_trusted_server \
-                                                        (sock, self.CRL_PATH)
+                    result_server_con = self.connect_trusted_server(
+                        sock, self.CRL_PATH)
                     if result_server_con in [1,2]:
                         raise Exception (1)
                     elif result_server_con == 3:
@@ -435,10 +436,10 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
         reply = show_question(self.ClientObj.MainWidget, text, inf_text,
                               title = _('Adding the certificate'))
 
-        if reply == QtGui.QMessageBox.No:
+        if reply == qt.QMessageBox.No:
             show_msg (_('Certificate not added to trusted'))
 
-        elif reply == QtGui.QMessageBox.Yes:
+        elif reply == qt.QMessageBox.Yes:
             list_ca_certs.append(cert)
             self.add_all_ca_cert(list_ca_certs)
         return
